avro\_to\_python package
========================

Subpackages
-----------

.. toctree::

    avro_to_python.reader
    avro_to_python.utils
    avro_to_python.writer

Submodules
----------

avro\_to\_python.cli module
---------------------------

.. automodule:: avro_to_python.cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: avro_to_python
    :members:
    :undoc-members:
    :show-inheritance:
